@@ -41,11 +41,6 @@ where
   type Item = A::Item;
 }
 
-#[cfg(feature = "with-staticvec")]
-impl<T, const N: usize> Storage for staticvec::StaticVec<T, N> {
-  type Item = T;
-}
-
 #[cfg(feature = "with-tinyvec")]
 impl<A> Storage for tinyvec::ArrayVec<A>
 where
